==> git-state-2.5.0.tgz: package/test.js <==
'use strict'

var test = require('tape')
var git = require('./')

test('#isGit()', function (t) {
  var dir = process.cwd()
  git.isGit(dir, function (exists) {
    t.equal(exists, true)
    t.end()
  })
})

test('#isGitSync()', function (t) {
  var dir = process.cwd()
  var result = git.isGitSync(dir)
  t.equal(result, true)
  t.end()
})

test('#check()', function (t) {
  var dir = process.cwd()
  git.check(dir, function (err, result) {
    t.error(err)
    t.deepEqual(Object.keys(result), ['branch', 'ahead', 'dirty', 'untracked', 'issues'])
    t.equal(typeof result.branch, 'string')
    t.equal(typeof result.ahead, 'number')
    t.equal(typeof result.dirty, 'number')
    t.equal(typeof result.untracked, 'number')
    t.equal(typeof result.issues, 'boolean')
    t.end()
  })
})

test('#untracked()', function (t) {
  var dir = process.cwd()
  git.untracked(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#dirty()', function (t) {
  var dir = process.cwd()
  git.dirty(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#branch()', function (t) {
  var dir = process.cwd()
  git.branch(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'string')
    t.end()
  })
})

test('#ahead()', function (t) {
  var dir = process.cwd()
  git.ahead(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#commit()', function (t) {
  var dir = process.cwd()
  git.commit(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'string')
    t.end()
  })
})

==> git-state-3.0.1.tgz: package/test.js <==
'use strict'

var test = require('tape')
var git = require('./')

test('#isGit()', function (t) {
  var dir = process.cwd()
  git.isGit(dir, function (exists) {
    t.equal(exists, true)
    t.end()
  })
})

test('#isGitSync()', function (t) {
  var dir = process.cwd()
  var result = git.isGitSync(dir)
  t.equal(result, true)
  t.end()
})

test('#check()', function (t) {
  var dir = process.cwd()
  git.check(dir, function (err, result) {
    t.error(err)
    t.deepEqual(Object.keys(result), ['branch', 'ahead', 'dirty', 'untracked', 'stashes'])
    t.equal(typeof result.branch, 'string')
    t.equal(typeof result.ahead, 'number')
    t.equal(typeof result.dirty, 'number')
    t.equal(typeof result.untracked, 'number')
    t.equal(typeof result.stashes, 'number')
    t.end()
  })
})

test('#untracked()', function (t) {
  var dir = process.cwd()
  git.untracked(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#dirty()', function (t) {
  var dir = process.cwd()
  git.dirty(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#branch()', function (t) {
  var dir = process.cwd()
  git.branch(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'string')
    t.end()
  })
})

test('#ahead()', function (t) {
  var dir = process.cwd()
  git.ahead(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})

test('#commit()', function (t) {
  var dir = process.cwd()
  git.commit(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'string')
    t.end()
  })
})

test('#stashes()', function (t) {
  var dir = process.cwd()
  git.stashes(dir, function (err, result) {
    t.error(err)
    t.equal(typeof result, 'number')
    t.end()
  })
})
